@@ -1,4 +1,4 @@
-#! python3.11
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
 # This Python script parses the Unicode data files in the UCD.zip file and
@@ -1781,4 +1781,4 @@ binary_dict = make_binary_dict()
 
 generate_code(unicode_data, UNICODE_VERSION, this_folder)
 
-print('\nSuccessfully generated _reges_unicode.h and _reges_unicode.c in %s' % tools_folder)
+print('\nSuccessfully generated _regex_unicode.h and _regex_unicode.c in %s' % tools_folder)
